..
    This file is part of Requirements-Builder
    Copyright (C) 2015 CERN.

    Requirements-Builder is free software; you can redistribute it and/or
    modify it under the terms of the Revised BSD License; see LICENSE
    file for more details.

.. include:: ../README.rst

Usage
=====

.. automodule:: requirements_builder


API Reference
=============

.. automodule:: requirements_builder.requirements_builder
   :members:
   :undoc-members:


.. include:: ../CONTRIBUTING.rst

.. include:: ../CHANGES.rst

License
=======

.. include:: ../LICENSE

.. include:: ../AUTHORS.rst
